pub struct Wakeup { /* private fields */ }Expand description
Used to indicate that we need to wake up the event loop.
This is a ZST used by the underlying event loop to wake up the event loop. It is not used directly by the user.
It is public because it is used by the Filter type. Generally, you don’t need to use it.