pub struct Filter<TS: ThreadSafety> { /* private fields */ }Expand description
The filter for passing events to async contexts.
This type takes events and passes them to the event handlers. It also handles the async contexts
that are waiting for events.
Implementations
Sourceimpl<TS: ThreadSafety> Filter<TS>
impl<TS: ThreadSafety> Filter<TS>
Sourcepub fn new(inner: &EventLoop<Wakeup>) -> Filter<TS>
pub fn new(inner: &EventLoop<Wakeup>) -> Filter<TS>
Create a new filter from an event loop.
The future is polled once before returning to set up event handlers.
Sourcepub fn handle_event<F>(
&mut self,
future: Pin<&mut F>,
event: Event<'_, Wakeup>,
elwt: &EventLoopWindowTarget<Wakeup>,
flow: &mut ControlFlow,
) -> ReturnOrFinish<(), F::Output>where
F: Future,
pub fn handle_event<F>(
&mut self,
future: Pin<&mut F>,
event: Event<'_, Wakeup>,
elwt: &EventLoopWindowTarget<Wakeup>,
flow: &mut ControlFlow,
) -> ReturnOrFinish<(), F::Output>where
F: Future,
Handle an event.
This function will block on the future if it is in the holding pattern.